#ifndef LIBWAHOO_H
#define LIBWAHOO_H

#include <stdint.h>

typedef struct __attribute__((packed)) libwahoo_workout_data {
    uint16_t workout_duration_sec;
    uint16_t horizontal_distance;
    uint8_t horizontal_distance_unit;
    uint16_t vertical_distance;
    uint8_t vertical_distance_unit;
    uint16_t calories_burned;
    uint8_t workout_program_id;
    uint8_t workout_program_level;
    uint16_t speed;
    uint8_t speed_unit;
    uint16_t pace;
    uint8_t pace_unit;
    uint16_t cadence;
    uint8_t cadence_unit;
    uint16_t grade;
    uint8_t grade_unit;
    uint8_t gear;
    uint16_t torque;
    uint8_t torque_unit;
    uint8_t heart_rate_bpm;
    uint16_t time_in_heart_rate_zone_sec;
    uint16_t mets_0_1_mets;
    uint16_t power;
    uint8_t power_unit;
    uint8_t average_heart_rate_bpm;
    uint8_t maximum_heart_rate_bpm;
} libwahoo_workout_data_t;

enum {
    LIBWAHOO_EVENT_ADVERTISING_STARTED,
    LIBWAHOO_EVENT_ADVERTISING_ENDED,
    LIBWAHOO_EVENT_CONNECTED,
    LIBWAHOO_EVENT_DISCONNECTED,
    LIBWAHOO_EVENT_HEARTRATE_VALUES,
    LIBWAHOO_EVENT_DEBUG,
    LIBWAHOO_EVENT_CALORIES_VALUES,
    LIBWAHOO_EVENT_USERNAME,
    LIBWAHOO_EVENT_WORKOUT_CONTROL_ACTION
};

enum {
    LIBWAHOO_EQUIPTYPE_NONE,
    LIBWAHOO_EQUIPTYPE_TREADMILL,
    LIBWAHOO_EQUIPTYPE_BIKE,
    LIBWAHOO_EQUIPTYPE_ELLIPTICAL,
    LIBWAHOO_EQUIPTYPE_STEPMILL
};

typedef struct libwahoo_t libwahoo_t;
typedef void (*libwahoo_event_cb_t)(int, void *, void *);

extern libwahoo_t * libwahoo_tuner_new(libwahoo_event_cb_t callback,
                                       void * callback_object);
extern void libwahoo_tuner_release(libwahoo_t * tuner);
extern void libwahoo_register_event_callback(libwahoo_t * tuner,
        libwahoo_event_cb_t cb);
extern void libwahoo_set_equipment_type(libwahoo_t * tuner, int equipment_type);
extern void libwahoo_start_advertising(libwahoo_t * tuner);
extern void libwahoo_stop_advertising(libwahoo_t * tuner);
extern void libwahoo_reboot(libwahoo_t * tuner);
extern void libwahoo_start_workout(libwahoo_t * tuner);
extern void libwahoo_stop_workout(libwahoo_t * tuner);
extern void libwahoo_pause_workout(libwahoo_t * tuner);
extern void libwahoo_update_workout(libwahoo_t * tuner,
                                    libwahoo_workout_data_t * data);

#endif
